@@ -4,7 +4,6 @@ import histogramVisTypeProvider from 'plugins/kbn_vislib_vis_types/histogram';
 import lineVisTypeProvider from 'plugins/kbn_vislib_vis_types/line';
 import pieVisTypeProvider from 'plugins/kbn_vislib_vis_types/pie';
 import areaVisTypeProvider from 'plugins/kbn_vislib_vis_types/area';
-import tileMapVisTypeProvider from 'plugins/kbn_vislib_vis_types/tile_map';
 import heatmapVisTypeProvider from 'plugins/kbn_vislib_vis_types/heatmap';
 import horizontalBarVisTypeProvider from 'plugins/kbn_vislib_vis_types/horizontal_bar';
 import gaugeVisTypeProvider from 'plugins/kbn_vislib_vis_types/gauge';
@@ -15,7 +14,6 @@ VisTypesRegistryProvider.register(histogramVisTypeProvider);
 VisTypesRegistryProvider.register(lineVisTypeProvider);
 VisTypesRegistryProvider.register(pieVisTypeProvider);
 VisTypesRegistryProvider.register(areaVisTypeProvider);
-VisTypesRegistryProvider.register(tileMapVisTypeProvider);
 VisTypesRegistryProvider.register(heatmapVisTypeProvider);
 VisTypesRegistryProvider.register(horizontalBarVisTypeProvider);
 VisTypesRegistryProvider.register(gaugeVisTypeProvider);
