@@ -1,6 +1,5 @@
 import _ from 'lodash';
 import angular from 'angular';
-import moment from 'moment';
 import { getSort } from 'ui/doc_table/lib/get_sort';
 import * as columnActions from 'ui/doc_table/actions/columns';
 import dateMath from '@elastic/datemath';
@@ -15,21 +14,21 @@ import 'ui/index_patterns';
 import 'ui/state_management/app_state';
 import 'ui/timefilter';
 import 'ui/share';
+import 'ui/query_bar';
 import { VisProvider } from 'ui/vis';
+import { BasicResponseHandlerProvider } from 'ui/vis/response_handlers/basic';
 import { DocTitleProvider } from 'ui/doc_title';
-import { UtilsBrushEventProvider } from 'ui/utils/brush_event';
 import PluginsKibanaDiscoverHitSortFnProvider from 'plugins/kibana/discover/_hit_sort_fn';
 import { FilterBarQueryFilterProvider } from 'ui/filter_bar/query_filter';
-import { FilterManagerProvider } from 'ui/filter_manager';
 import { AggTypesBucketsIntervalOptionsProvider } from 'ui/agg_types/buckets/_interval_options';
 import { stateMonitorFactory } from 'ui/state_management/state_monitor_factory';
 import uiRoutes from 'ui/routes';
 import { uiModules } from 'ui/modules';
 import indexTemplate from 'plugins/kibana/discover/index.html';
 import { StateProvider } from 'ui/state_management/state';
-import { documentationLinks } from 'ui/documentation_links/documentation_links';
+import { migrateLegacyQuery } from 'ui/utils/migrateLegacyQuery';
+import { QueryManagerProvider } from 'ui/query_manager';
 import { SavedObjectsClientProvider } from 'ui/saved_objects';
-import { getDefaultQuery } from 'ui/parse_query';
 
 const app = uiModules.get('apps/discover', [
   'kibana/notify',
@@ -97,23 +96,34 @@ app.directive('discoverApp', function () {
   };
 });
 
-function discoverController($scope, config, courier, $route, $window, Notifier,
-  AppState, timefilter, Promise, Private, kbnUrl) {
+function discoverController(
+  $element,
+  $route,
+  $scope,
+  $timeout,
+  $window,
+  AppState,
+  Notifier,
+  Private,
+  Promise,
+  config,
+  courier,
+  kbnUrl,
+  timefilter,
+) {
 
   const Vis = Private(VisProvider);
   const docTitle = Private(DocTitleProvider);
-  const brushEvent = Private(UtilsBrushEventProvider);
   const HitSortFn = Private(PluginsKibanaDiscoverHitSortFnProvider);
   const queryFilter = Private(FilterBarQueryFilterProvider);
-  const filterManager = Private(FilterManagerProvider);
-
+  const responseHandler = Private(BasicResponseHandlerProvider).handler;
   const notify = new Notifier({
     location: 'Discover'
   });
 
-  $scope.queryDocLinks = documentationLinks.query;
   $scope.intervalOptions = Private(AggTypesBucketsIntervalOptionsProvider);
   $scope.showInterval = false;
+  $scope.minimumVisibleRows = 50;
 
   $scope.intervalEnabled = function (interval) {
     return interval.val !== 'custom';
@@ -163,14 +173,86 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
   const $appStatus = $scope.appStatus = this.appStatus = {
     dirty: !savedSearch.id
   };
+
   const $state = $scope.state = new AppState(getStateDefaults());
+  const queryManager = Private(QueryManagerProvider)($state);
+
+  const getFieldCounts = async () => {
+    // the field counts aren't set until we have the data back,
+    // so we wait for the fetch to be done before proceeding
+    if (!$scope.fetchStatus) {
+      return $scope.fieldCounts;
+    }
+
+    return await new Promise(resolve => {
+      const unwatch = $scope.$watch('fetchStatus', (newValue) => {
+        if (newValue) {
+          return;
+        }
+
+        unwatch();
+        resolve($scope.fieldCounts);
+      });
+    });
+  };
+
+
+  const getSharingDataFields = async () => {
+    const selectedFields = $state.columns;
+    if (selectedFields.length === 1 && selectedFields[0] ===  '_source') {
+      const fieldCounts = await getFieldCounts();
+      return {
+        searchFields: null,
+        selectFields: _.keys(fieldCounts).sort()
+      };
+    }
+
+    const timeFieldName = $scope.indexPattern.timeFieldName;
+    const fields = timeFieldName ? [timeFieldName, ...selectedFields] : selectedFields;
+    return {
+      searchFields: fields,
+      selectFields: fields
+    };
+  };
+
+  this.getSharingData = async () => {
+    const searchSource = $scope.searchSource.clone();
+
+    const { searchFields, selectFields } = await getSharingDataFields();
+    searchSource.set('fields', searchFields);
+    searchSource.set('sort', getSort($state.sort, $scope.indexPattern));
+    searchSource.set('highlight', null);
+    searchSource.set('highlightAll', null);
+    searchSource.set('aggs', null);
+    searchSource.set('size', null);
+
+    const body = await searchSource.getSearchRequestBody();
+    return {
+      searchRequest: {
+        index: searchSource.get('index').title,
+        body
+      },
+      fields: selectFields,
+      metaFields: $scope.indexPattern.metaFields,
+      conflictedTypesFields: $scope.indexPattern.fields.filter(f => f.type === 'conflict').map(f => f.name),
+      indexPatternId: searchSource.get('index').id
+    };
+  };
+
+  this.getSharingType = () => {
+    return 'search';
+  };
+
+  this.getSharingTitle = () => {
+    return savedSearch.title;
+  };
 
   $scope.uiState = $state.makeStateful('uiState');
 
   function getStateDefaults() {
     return {
-      query: $scope.searchSource.get('query') || getDefaultQuery(),
-      sort: getSort.array(savedSearch.sort, $scope.indexPattern),
+      query: $scope.searchSource.get('query') || { query: '', language: config.get('search:queryLanguage') },
+      sort: getSort.array(savedSearch.sort, $scope.indexPattern, config.get('discover:sort:defaultOrder')),
       columns: savedSearch.columns.length > 0 ? savedSearch.columns : config.get('defaultColumns').slice(),
       index: $scope.indexPattern.id,
       interval: 'auto',
@@ -249,17 +331,28 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
         $scope.fetch();
       });
 
+      // Necessary for handling new time filters when the date histogram is clicked
+      $scope.$watchCollection('state.$newFilters', function (filters = []) {
+        // need to convert filters generated from user interaction with viz into kuery AST
+        // These are handled by the filter bar directive when lucene is the query language
+        Promise.all(filters.map(queryManager.addLegacyFilter))
+        .then(() => $scope.state.$newFilters = [])
+        .then($scope.fetch);
+      });
+
       $scope.$watch('vis.aggs', function () {
         // no timefield, no vis, nothing to update
         if (!$scope.opts.timefield) return;
 
-        const buckets = $scope.vis.aggs.bySchemaGroup.buckets;
+        const buckets = $scope.vis.getAggConfig().bySchemaGroup.buckets;
 
         if (buckets && buckets.length === 1) {
           $scope.bucketInterval = buckets[0].buckets.getInterval();
         }
       });
 
+      $scope.$watch('state.query', $scope.updateQueryAndFetch);
+
       $scope.$watchMulti([
         'rows',
         'fetchStatus'
@@ -362,6 +455,15 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
     .catch(notify.error);
   };
 
+  $scope.updateQueryAndFetch = function (query) {
+    // reset state if language changes
+    if ($state.query.language && $state.query.language !== query.language) {
+      $state.filters = [];
+    }
+    $state.query = migrateLegacyQuery(query);
+    $scope.fetch();
+  };
+
   $scope.searchSource.onBeginSegmentedFetch(function (segmented) {
     function flushResponseData() {
       $scope.hits = 0;
@@ -386,7 +488,7 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
      * @type {String}
      */
     const sortBy = (function () {
-      if (!_.isArray(sort)) return 'implicit';
+      if (!Array.isArray(sort)) return 'implicit';
       else if (sort[0] === '_score') return 'implicit';
       else if (sort[0] === timeField) return 'time';
       else return 'non-time';
@@ -423,6 +525,14 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
 
     segmented.on('mergedSegment', function (merged) {
       $scope.mergedEsResp = merged;
+
+      if ($scope.opts.timefield) {
+        $scope.searchSource.rawResponse = merged;
+        responseHandler($scope.vis, merged).then(resp => {
+          $scope.visData = resp;
+        });
+      }
+
       $scope.hits = merged.hits.total;
 
       const indexPattern = $scope.searchSource.get('index');
@@ -494,7 +604,7 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
   // TODO: On array fields, negating does not negate the combination, rather all terms
   $scope.filterQuery = function (field, values, operation) {
     $scope.indexPattern.popularizeField(field, 1);
-    filterManager.add(field, values, operation, $state.index);
+    queryManager.add(field, values, operation, $scope.indexPattern.id);
   };
 
   $scope.addColumn = function addColumn(columnName) {
@@ -511,10 +621,21 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
     columnActions.moveColumn($scope.state.columns, columnName, newIndex);
   };
 
-  $scope.toTop = function () {
+  $scope.scrollToTop = function () {
     $window.scrollTo(0, 0);
   };
 
+  $scope.scrollToBottom = function () {
+    // delay scrolling to after the rows have been rendered
+    $timeout(() => {
+      $element.find('#discoverBottomMarker').focus();
+    }, 0);
+  };
+
+  $scope.showAllRows = function () {
+    $scope.minimumVisibleRows = $scope.hits;
+  };
+
   let loadingVis;
   function setupVisualization() {
     // If we're not setting anything up we need to return an empty promise
@@ -552,21 +673,15 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
         addLegend: false,
         addTimeMarker: true
       },
-      listeners: {
-        click: function (e) {
-          notify.log(e);
-          timefilter.time.from = moment(e.point.x);
-          timefilter.time.to = moment(e.point.x + e.data.ordered.interval);
-          timefilter.time.mode = 'absolute';
-        },
-        brush: brushEvent($scope.state)
-      },
       aggs: visStateAggs
     });
 
+    $scope.searchSource.onRequestStart(() => {
+      return $scope.vis.requesting();
+    });
+
     $scope.searchSource.aggs(function () {
-      $scope.vis.requesting();
-      return $scope.vis.aggs.toDsl();
+      return $scope.vis.getAggConfig().toDsl();
     });
 
     // stash this promise so that other calls to setupVisualization will have to wait
@@ -595,11 +710,11 @@ function discoverController($scope, config, courier, $route, $window, Notifier,
     if (stateVal && !stateValFound) {
       const err = '"' + stateVal + '" is not a configured pattern ID. ';
       if (own) {
-        notify.warning(err + ' Using the saved index pattern: "' + own.id + '"');
+        notify.warning(`${err} Using the saved index pattern: "${own.title}" (${own.id})`);
         return own;
       }
 
-      notify.warning(err + ' Using the default index pattern: "' + loaded.id + '"');
+      notify.warning(`${err} Using the default index pattern: "${loaded.title}" (${loaded.id})`);
     }
     return loaded;
   }
