@@ -1,26 +1,27 @@
 import _ from 'lodash';
 import 'plugins/kibana/visualize/saved_visualizations/saved_visualizations';
-import 'plugins/kibana/visualize/editor/sidebar';
+import 'ui/vis/editors/default/sidebar';
 import 'plugins/kibana/visualize/editor/agg_filter';
 import 'ui/visualize';
 import 'ui/collapsible_sidebar';
 import 'ui/share';
+import 'ui/query_bar';
 import chrome from 'ui/chrome';
 import angular from 'angular';
 import { Notifier } from 'ui/notify/notifier';
 import { VisTypesRegistryProvider } from 'ui/registry/vis_types';
 import { DocTitleProvider } from 'ui/doc_title';
-import { UtilsBrushEventProvider } from 'ui/utils/brush_event';
 import { FilterBarQueryFilterProvider } from 'ui/filter_bar/query_filter';
-import { FilterBarClickHandlerProvider } from 'ui/filter_bar/filter_bar_click_handler';
 import { stateMonitorFactory } from 'ui/state_management/state_monitor_factory';
 import uiRoutes from 'ui/routes';
 import { uiModules } from 'ui/modules';
 import editorTemplate from 'plugins/kibana/visualize/editor/editor.html';
 import { DashboardConstants } from 'plugins/kibana/dashboard/dashboard_constants';
 import { VisualizeConstants } from '../visualize_constants';
-import { documentationLinks } from 'ui/documentation_links/documentation_links';
-import { getDefaultQuery } from 'ui/parse_query';
+import { KibanaParsedUrl } from 'ui/url/kibana_parsed_url';
+import { absoluteToParsedUrl } from 'ui/url/absolute_to_parsed_url';
+import { migrateLegacyQuery } from 'ui/utils/migrateLegacyQuery';
+import { QueryManagerProvider } from 'ui/query_manager';
 
 uiRoutes
 .when(VisualizeConstants.CREATE_PATH, {
@@ -29,7 +30,9 @@ uiRoutes
     savedVis: function (savedVisualizations, courier, $route, Private) {
       const visTypes = Private(VisTypesRegistryProvider);
       const visType = _.find(visTypes, { name: $route.current.params.type });
-      if (visType.requiresSearch && !$route.current.params.indexPattern && !$route.current.params.savedSearchId) {
+      const shouldHaveIndex = visType.requiresSearch && visType.options.showIndexSelection;
+      const hasIndex = $route.current.params.indexPattern || $route.current.params.savedSearchId;
+      if (shouldHaveIndex && !hasIndex) {
         throw new Error('You must provide either an indexPattern or a savedSearchId');
       }
 
@@ -68,52 +71,34 @@ uiModules
   };
 });
 
-function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kbnUrl, courier, Private, Promise, kbnBaseUrl) {
+function VisEditor($scope, $route, timefilter, AppState, $window, kbnUrl, courier, Private, Promise, config, kbnBaseUrl) {
   const docTitle = Private(DocTitleProvider);
-  const brushEvent = Private(UtilsBrushEventProvider);
   const queryFilter = Private(FilterBarQueryFilterProvider);
-  const filterBarClickHandler = Private(FilterBarClickHandlerProvider);
 
   const notify = new Notifier({
     location: 'Visualization Editor'
   });
 
-  let stateMonitor;
-
   // Retrieve the resolved SavedVis instance.
   const savedVis = $route.current.locals.savedVis;
-
-  const $appStatus = this.appStatus = {
-    dirty: !savedVis.id
-  };
-
-  // Instance of src/ui/public/vis/vis.js.
-  const vis = savedVis.vis;
-
-  // Clone the _vis instance.
-  const editableVis = vis.createEditableVis();
-
-  // We intend to keep editableVis and vis in sync with one another, so calling `requesting` on
-  // vis should call it on both.
-  vis.requesting = function () {
-    const requesting = editableVis.requesting;
-    // Invoking requesting() calls onRequest on each agg's type param. When a vis is marked as being
-    // requested, the bounds of that vis are updated and new data is fetched using the new bounds.
-    requesting.call(vis);
-
-    // We need to keep editableVis in sync with vis.
-    requesting.call(editableVis);
-  };
-
-  // SearchSource is a promise-based stream of search results that can inherit from other search
-  // sources.
-  const searchSource = savedVis.searchSource;
+  // vis is instance of src/ui/public/vis/vis.js.
+  // SearchSource is a promise-based stream of search results that can inherit from other search sources.
+  const { vis, searchSource } = savedVis;
+  $scope.vis = vis;
 
   $scope.topNavMenu = [{
     key: 'save',
     description: 'Save Visualization',
     template: require('plugins/kibana/visualize/editor/panels/save.html'),
     testId: 'visualizeSaveButton',
+    disableButton() {
+      return Boolean(vis.dirty);
+    },
+    tooltip() {
+      if (vis.dirty) {
+        return 'Apply or Discard your changes before saving';
+      }
+    }
   }, {
     key: 'share',
     description: 'Share Visualization',
@@ -122,10 +107,18 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
   }, {
     key: 'refresh',
     description: 'Refresh',
-    run: function () { $scope.fetch(); },
+    run: function () {
+      vis.forceReload();
+    },
     testId: 'visualizeRefreshButton',
   }];
 
+  let stateMonitor;
+
+  const $appStatus = this.appStatus = {
+    dirty: !savedVis.id
+  };
+
   if (savedVis.id) {
     docTitle.change(savedVis.title);
   }
@@ -136,13 +129,13 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
   const stateDefaults = {
     uiState: savedVis.uiStateJSON ? JSON.parse(savedVis.uiStateJSON) : {},
     linked: !!savedVis.savedSearchId,
-    query: searchSource.getOwn('query') || getDefaultQuery(),
+    query: searchSource.getOwn('query') || { query: '', language: config.get('search:queryLanguage') },
     filters: searchSource.getOwn('filter') || [],
     vis: savedVisState
   };
 
   // Instance of app_state.js.
-  const $state = $scope.$state = (function initState() {
+  const $state = (function initState() {
     // This is used to sync visualization state with the url when `appState.save()` is called.
     const appState = new AppState(stateDefaults);
 
@@ -151,8 +144,7 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
     // appState then they won't be equal.
     if (!angular.equals(appState.vis, savedVisState)) {
       Promise.try(function () {
-        editableVis.setState(appState.vis);
-        vis.setState(editableVis.getEnabledState());
+        vis.setState(appState.vis);
       })
       .catch(courier.redirectWhenMissing({
         'index-pattern-field': '/visualize'
@@ -161,17 +153,14 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
 
     return appState;
   }());
+  const queryManager = Private(QueryManagerProvider)($state);
 
   function init() {
     // export some objects
     $scope.savedVis = savedVis;
-    $scope.searchSource = searchSource;
-    $scope.vis = vis;
     $scope.indexPattern = vis.indexPattern;
-    $scope.editableVis = editableVis;
+    $scope.searchSource = searchSource;
     $scope.state = $state;
-    $scope.queryDocLinks = documentationLinks.query;
-    $scope.dateDocLinks = documentationLinks.date;
 
     // Create a PersistedState instance.
     $scope.uiState = $state.makeStateful('uiState');
@@ -195,30 +184,16 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
     stateMonitor.ignoreProps([ 'vis.listeners' ]).onChange((status) => {
       $appStatus.dirty = status.dirty || !savedVis.id;
     });
-    $scope.$on('$destroy', () => stateMonitor.destroy());
 
-    editableVis.listeners.click = vis.listeners.click = filterBarClickHandler($state);
-    editableVis.listeners.brush = vis.listeners.brush = brushEvent($state);
+    $scope.$watchCollection('state.$newFilters', function (filters = []) {
+      // need to convert filters generated from user interaction with viz into kuery AST
+      // These are handled by the filter bar directive when lucene is the query language
+      Promise.all(filters.map(queryManager.addLegacyFilter))
+      .then(() => $scope.state.$newFilters = [])
+      .then($scope.fetch);
+    });
 
-    // track state of editable vis vs. "actual" vis
-    $scope.stageEditableVis = transferVisState(editableVis, vis, true);
-    $scope.resetEditableVis = transferVisState(vis, editableVis);
-    $scope.$watch(function () {
-      return editableVis.getEnabledState();
-    }, function (newState) {
-      editableVis.dirty = !angular.equals(newState, vis.getEnabledState());
-
-      $scope.responseValueAggs = null;
-      try {
-        $scope.responseValueAggs = editableVis.aggs.getResponseAggs().filter(function (agg) {
-          return _.get(agg, 'schema.group') === 'metrics';
-        });
-      }
-      // this can fail when the agg.type is changed but the
-      // params have not been set yet. watcher will trigger again
-      // when the params update
-      catch (e) {} // eslint-disable-line no-empty
-    }, true);
+    $scope.$watch('state.query', $scope.updateQueryAndFetch);
 
     $state.replace();
 
@@ -227,57 +202,22 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
     };
 
     $scope.$watchMulti([
-      'searchSource.get("index").timeFieldName',
-      'vis.type.requiresTimePicker',
-    ], function ([timeField, requiresTimePicker]) {
-      timefilter.enabled = Boolean(timeField || requiresTimePicker);
+      'searchSource.get("index")',
+      'vis.type.options.showTimePicker',
+    ], function ([index, requiresTimePicker]) {
+      timefilter.enabled = Boolean((!index || index.timeFieldName) && requiresTimePicker);
     });
 
     // update the searchSource when filters update
     $scope.$listen(queryFilter, 'update', function () {
-      searchSource.set('filter', queryFilter.getFilters());
       $state.save();
     });
 
-    // fetch data when filters fire fetch event
-    $scope.$listen(queryFilter, 'fetch', $scope.fetch);
-
-
-    $scope.$listen($state, 'fetch_with_changes', function (keys) {
-      if (_.contains(keys, 'linked') && $state.linked === true) {
-        // abort and reload route
-        $route.reload();
-        return;
-      }
-
-      if (_.contains(keys, 'vis')) {
-        $state.vis.listeners = _.defaults($state.vis.listeners || {}, vis.listeners);
-
-        // only update when we need to, otherwise colors change and we
-        // risk loosing an in-progress result
-        vis.setState($state.vis);
-        editableVis.setState($state.vis);
-      }
-
-      // we use state to track query, must write before we fetch
-      if ($state.query && !$state.linked) {
-        searchSource.set('query', $state.query);
-      } else {
-        searchSource.set('query', null);
-      }
-
-      if (_.isEqual(keys, ['filters'])) {
-        // updates will happen in filter watcher if needed
-        return;
-      }
-
-      $scope.fetch();
-    });
-
-    // Without this manual emission, we'd miss filters and queries that were on the $state initially
-    $state.emit('fetch_with_changes');
-
-    $scope.$listen(timefilter, 'fetch', _.bindKey($scope, 'fetch'));
+    // update the searchSource when query updates
+    $scope.fetch = function () {
+      $state.save();
+      $scope.vis.forceReload();
+    };
 
     $scope.$on('ready:vis', function () {
       $scope.$emit('application.load');
@@ -285,18 +225,18 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
 
     $scope.$on('$destroy', function () {
       savedVis.destroy();
+      stateMonitor.destroy();
     });
   }
 
-  $scope.fetch = function () {
-    // This is used by some plugins to trigger a fetch (Timelion and Time Series Visual Builder)
-    $rootScope.$broadcast('fetch');
-    $state.save();
-    searchSource.set('filter', queryFilter.getFilters());
-    if (!$state.linked) searchSource.set('query', $state.query);
-    if ($scope.vis.type.requiresSearch) {
-      courier.fetch();
+  $scope.updateQueryAndFetch = function (query) {
+    // reset state if language changes
+    if ($state.query.language && $state.query.language !== query.language) {
+      $state.filters = [];
+      $state.$newFilters = [];
     }
+    $state.query = migrateLegacyQuery(query);
+    $scope.fetch();
   };
 
   /**
@@ -317,20 +257,22 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
       if (id) {
         notify.info('Saved Visualization "' + savedVis.title + '"');
         if ($scope.isAddToDashMode()) {
-          const savedVisualizationUrl =
-            kbnUrl.eval(`${kbnBaseUrl}#${VisualizeConstants.EDIT_PATH}/{{id}}`, { id: savedVis.id });
-
+          const savedVisualizationParsedUrl = new KibanaParsedUrl({
+            basePath: chrome.getBasePath(),
+            appId: kbnBaseUrl.slice('/app/'.length),
+            appPath: kbnUrl.eval(`${VisualizeConstants.EDIT_PATH}/{{id}}`, { id: savedVis.id }),
+          });
           // Manually insert a new url so the back button will open the saved visualization.
-          $window.history.pushState({}, '', `${chrome.getBasePath()}${savedVisualizationUrl}`);
+          $window.history.pushState({}, '', savedVisualizationParsedUrl.getRootRelativePath());
           // Since we aren't reloading the page, only inserting a new browser history item, we need to manually update
           // the last url for this app, so directly clicking on the Visualize tab will also bring the user to the saved
           // url, not the unsaved one.
-          chrome.trackSubUrlForApp('kibana:visualize', savedVisualizationUrl);
+          chrome.trackSubUrlForApp('kibana:visualize', savedVisualizationParsedUrl);
 
-          const dashboardBaseUrl = chrome.getNavLinkById('kibana:dashboard');
-          const dashUrlPieces = dashboardBaseUrl.lastSubUrl.match(/(.*)kibana#(.*)/);
-          const dashSubUrl = `${dashUrlPieces[2]}&${DashboardConstants.NEW_VISUALIZATION_ID_PARAM}={{id}}`;
-          kbnUrl.change(dashSubUrl, { id: savedVis.id });
+          const lastDashboardAbsoluteUrl = chrome.getNavLinkById('kibana:dashboard').lastSubUrl;
+          const dashboardParsedUrl = absoluteToParsedUrl(lastDashboardAbsoluteUrl, chrome.getBasePath());
+          dashboardParsedUrl.addQueryParameter(DashboardConstants.NEW_VISUALIZATION_ID_PARAM, savedVis.id);
+          kbnUrl.change(dashboardParsedUrl.appPath);
         } else if (savedVis.id === $route.current.params.id) {
           docTitle.change(savedVis.lastSavedTitle);
         } else {
@@ -352,9 +294,9 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
     delete savedVis.savedSearchId;
     parent.set('filter', _.union(searchSource.getOwn('filter'), parent.getOwn('filter')));
 
-    // copy over all state except "aggs" and filter, which is already copied
+    // copy over all state except "aggs", "query" and "filter"
     _(parent.toJSON())
-    .omit('aggs')
+    .omit(['aggs', 'filter', 'query'])
     .forOwn(function (val, key) {
       searchSource.set(key, val);
     })
@@ -363,31 +305,9 @@ function VisEditor($rootScope, $scope, $route, timefilter, AppState, $window, kb
     $state.query = searchSource.get('query');
     $state.filters = searchSource.get('filter');
     searchSource.inherits(parentsParent);
+
+    $scope.fetch();
   };
 
-  function transferVisState(fromVis, toVis, stage) {
-    return function () {
-
-      //verify this before we copy the "new" state
-      const isAggregationsChanged = !fromVis.aggs.jsonDataEquals(toVis.aggs);
-
-      const view = fromVis.getEnabledState();
-      const full = fromVis.getState();
-      toVis.setState(view);
-      editableVis.dirty = false;
-      $state.vis = full;
-
-      /**
-       * Only fetch (full ES round trip), if the play-button has been pressed (ie. 'stage' variable) and if there
-       * has been changes in the Data-tab.
-       */
-      if (stage && isAggregationsChanged) {
-        $scope.fetch();
-      } else {
-        $state.save();
-      }
-    };
-  }
-
   init();
 }
