@@ -281,7 +281,7 @@ class TagCloud extends EventEmitter {
           y: tag.y,
           rotate: tag.rotate,
           size: tag.size,
-          rawText: tag.text,
+          rawText: tag.rawText || tag.text,
           displayText: tag.displayText
         };
       })
@@ -304,6 +304,12 @@ class TagCloud extends EventEmitter {
 
   async _updateLayout(job) {
 
+    if (job.size[0] <= 0 || job.size[1] <= 0) {
+      // If either width or height isn't above 0 we don't relayout anything,
+      // since the d3-cloud will be stuck in an infinite loop otherwise.
+      return;
+    }
+
     const mapSizeToFontSize = this._makeTextSizeMapper();
     const tagCloudLayoutGenerator = d3TagCloud();
     tagCloudLayoutGenerator.size(job.size);
@@ -339,7 +345,7 @@ class TagCloud extends EventEmitter {
     debug.positions = this._completedJob ? this._completedJob.words.map(tag => {
       return {
         displayText: tag.displayText,
-        rawText: tag.text,
+        rawText: tag.rawText || tag.text,
         x: tag.x,
         y: tag.y,
         rotate: tag.rotate
