@@ -13,6 +13,7 @@ uiModules.get('kibana/table_vis')
       link: function ($scope, $element) {
         const sliderContainer = $element[0];
         const slider = sliderContainer.querySelector('.tag-cloud-fontsize-slider');
+        $scope.config = $scope.vis.type.editorConfig;
         noUiSlider.create(slider, {
           start: [$scope.vis.params.minFontSize, $scope.vis.params.maxFontSize],
           connect: true,
@@ -23,9 +24,21 @@ uiModules.get('kibana/table_vis')
         });
         slider.noUiSlider.on('change', function () {
           const fontSize = slider.noUiSlider.get();
-          $scope.vis.params.minFontSize = parseInt(fontSize[0], 10);
-          $scope.vis.params.maxFontSize = parseInt(fontSize[1], 10);
-          $scope.$apply();
+          $scope.$apply(() => {
+            $scope.vis.params.minFontSize = parseInt(fontSize[0], 10);
+            $scope.vis.params.maxFontSize = parseInt(fontSize[1], 10);
+          });
+        });
+
+        /**
+         * Whenever the params change (e.g. by hitting reset in the editor)
+         * set the uislider value to the new value.
+         */
+        $scope.$watch('vis.params.minFontSize', (val) => {
+          slider.noUiSlider.set([val, null]);
+        });
+        $scope.$watch('vis.params.maxFontSize', (val) => {
+          slider.noUiSlider.set([null, val]);
         });
       }
     };
