@@ -38,7 +38,9 @@ export function kbnChromeProvider(chrome, internals) {
         const getUnhashableStates = Private(getUnhashableStatesProvider);
 
         // are we showing the embedded version of the chrome?
-        internals.setVisibleDefault(!$location.search().embed);
+        if (Boolean($location.search().embed)) {
+          internals.permanentlyHideChrome();
+        }
 
         const subUrlRouteFilter = Private(SubUrlRouteFilterProvider);
 
