@@ -2,8 +2,8 @@ import 'angular-ui-select';
 import { uiModules } from 'ui/modules';
 import template from './filter_params_phrase_editor.html';
 import { filterParamsPhraseController } from './filter_params_phrase_controller';
-import { documentationLinks } from 'ui/documentation_links/documentation_links';
 import './filter_params_input_type';
+import '../../directives/documentation_href';
 import '../../directives/ui_select_focus_on';
 import '../../directives/focus_on';
 import '../../filters/sort_prefix_first';
@@ -18,9 +18,6 @@ module.directive('filterParamsPhraseEditor', function () {
       params: '='
     },
     controllerAs: 'filterParamsPhraseEditor',
-    controller: filterParamsPhraseController,
-    link: function (scope) {
-      scope.dateDocLinks = documentationLinks.date;
-    }
+    controller: filterParamsPhraseController
   };
 });
