@@ -11,42 +11,46 @@ import { IndexPatternsGetProvider } from './_get';
 import { IndexPatternsIntervalsProvider } from './_intervals';
 import { IndexPatternsFieldListProvider } from './_field_list';
 import { IndexPatternsFlattenHitProvider } from './_flatten_hit';
-import { IndexPatternsCalculateIndicesProvider } from './_calculate_indices';
 import { IndexPatternsPatternCacheProvider } from './_pattern_cache';
 import { FieldsFetcherProvider } from './fields_fetcher_provider';
+import { IsUserAwareOfUnsupportedTimePatternProvider } from './unsupported_time_patterns';
 import { SavedObjectsClientProvider, findObjectByTitle } from 'ui/saved_objects';
 
-export function IndexPatternProvider(Private, $http, config, kbnIndex, Promise, confirmModalPromise, kbnUrl) {
+export function getRoutes() {
+  return {
+    edit: '/management/kibana/indices/{{id}}',
+    addField: '/management/kibana/indices/{{id}}/create-field',
+    indexedFields: '/management/kibana/indices/{{id}}?_a=(tab:indexedFields)',
+    scriptedFields: '/management/kibana/indices/{{id}}?_a=(tab:scriptedFields)',
+    sourceFilters: '/management/kibana/indices/{{id}}?_a=(tab:sourceFilters)'
+  };
+}
+
+export function IndexPatternProvider(Private, config, Promise, confirmModalPromise, kbnUrl) {
   const fieldformats = Private(RegistryFieldFormatsProvider);
+  const getConfig = (...args) => config.get(...args);
   const getIds = Private(IndexPatternsGetProvider)('id');
   const fieldsFetcher = Private(FieldsFetcherProvider);
   const intervals = Private(IndexPatternsIntervalsProvider);
   const mappingSetup = Private(UtilsMappingSetupProvider);
   const FieldList = Private(IndexPatternsFieldListProvider);
   const flattenHit = Private(IndexPatternsFlattenHitProvider);
-  const calculateIndices = Private(IndexPatternsCalculateIndicesProvider);
   const patternCache = Private(IndexPatternsPatternCacheProvider);
+  const isUserAwareOfUnsupportedTimePattern = Private(IsUserAwareOfUnsupportedTimePatternProvider);
+  const savedObjectsClient = Private(SavedObjectsClientProvider);
+
   const type = 'index-pattern';
   const notify = new Notifier();
   const configWatchers = new WeakMap();
-  const getRoutes = () => ({
-    edit: '/management/kibana/indices/{{id}}',
-    addField: '/management/kibana/indices/{{id}}/create-field',
-    indexedFields: '/management/kibana/indices/{{id}}?_a=(tab:indexedFields)',
-    scriptedFields: '/management/kibana/indices/{{id}}?_a=(tab:scriptedFields)',
-    sourceFilters: '/management/kibana/indices/{{id}}?_a=(tab:sourceFilters)'
-  });
-  const savedObjectsClient = Private(SavedObjectsClientProvider);
 
   const mapping = mappingSetup.expandShorthand({
-    title: 'string',
-    timeFieldName: 'string',
-    notExpandable: 'boolean',
-    intervalName: 'string',
+    title: 'text',
+    timeFieldName: 'keyword',
+    intervalName: 'keyword',
     fields: 'json',
     sourceFilters: 'json',
     fieldFormatMap: {
-      type: 'string',
+      type: 'text',
       _serialize(map = {}) {
         const serialized = _.transform(map, serializeFieldFormatMap);
         return _.isEmpty(serialized) ? undefined : angular.toJson(serialized);
@@ -65,7 +69,7 @@ export function IndexPatternProvider(Private, $http, config, kbnIndex, Promise,
 
   function deserializeFieldFormatMap(mapping) {
     const FieldFormat = fieldformats.byId[mapping.id];
-    return FieldFormat && new FieldFormat(mapping.params);
+    return FieldFormat && new FieldFormat(mapping.params, getConfig);
   }
 
   function updateFromElasticSearch(indexPattern, response) {
@@ -89,6 +93,22 @@ export function IndexPatternProvider(Private, $http, config, kbnIndex, Promise,
     // give index pattern all of the values in _source
     _.assign(indexPattern, response._source);
 
+    if (!indexPattern.title) {
+      indexPattern.title = indexPattern.id;
+    }
+
+    if (indexPattern.isUnsupportedTimePattern()) {
+      if (!isUserAwareOfUnsupportedTimePattern(indexPattern)) {
+        const warning = (
+          'Support for time-intervals has been removed. ' +
+          `View the ["${indexPattern.title}" index pattern in management](` +
+          kbnUrl.getRouteHref(indexPattern, 'edit') +
+          ') for more information.'
+        );
+        notify.warning(warning, { lifetime: Infinity });
+      }
+    }
+
     return indexFields(indexPattern);
   }
 
@@ -165,13 +185,6 @@ export function IndexPatternProvider(Private, $http, config, kbnIndex, Promise,
     });
   }
 
-  function isFieldStatsError(error) {
-    return (
-      error.statusCode === 400
-      && (error.message || '').includes('_field_stats')
-    );
-  }
-
   class IndexPattern {
     constructor(id) {
       setId(this, id);
@@ -273,43 +286,29 @@ export function IndexPatternProvider(Private, $http, config, kbnIndex, Promise,
       return this
         .toDetailedIndexList(start, stop, sortDirection)
         .then(detailedIndices => {
-          if (!_.isArray(detailedIndices)) {
+          if (!Array.isArray(detailedIndices)) {
             return detailedIndices.index;
           }
           return _.pluck(detailedIndices, 'index');
         });
     }
 
-    async toDetailedIndexList(start, stop, sortDirection) {
-      if (this.isTimeBasedInterval()) {
-        return await intervals.toIndexList(
-          this.title, this.getInterval(), start, stop, sortDirection
-        );
-      }
-
-      if (this.isTimeBasedWildcard() && this.isIndexExpansionEnabled()) {
-        try {
-          return await calculateIndices(
-            this.title, this.timeFieldName, start, stop, sortDirection
+    toDetailedIndexList(start, stop, sortDirection) {
+      return Promise.resolve().then(() => {
+        if (this.isTimeBasedInterval()) {
+          return intervals.toIndexList(
+            this.title, this.getInterval(), start, stop, sortDirection
           );
-        } catch(error) {
-          if (!isFieldStatsError(error)) {
-            throw error;
+        }
+
+        return [
+          {
+            index: this.title,
+            min: -Infinity,
+            max: Infinity
           }
-        }
-      }
-
-      return [
-        {
-          index: this.title,
-          min: -Infinity,
-          max: Infinity
-        }
-      ];
-    }
-
-    isIndexExpansionEnabled() {
-      return !this.notExpandable;
+        ];
+      });
     }
 
     isTimeBased() {
@@ -320,6 +319,10 @@ export function IndexPatternProvider(Private, $http, config, kbnIndex, Promise,
       return this.isTimeBased() && !!this.getInterval();
     }
 
+    isUnsupportedTimePattern() {
+      return !!this.intervalName;
+    }
+
     isTimeBasedWildcard() {
       return this.isTimeBased() && this.isWildcard();
     }
